import React from "react";
import PropTypes from "prop-types";
import { Grid } from "@material-ui/core";
import { makeStyles } from "@material-ui/core/styles";
import { CheckCircleOutlineRounded, RemoveRounded } from "@material-ui/icons";

const useStyles = makeStyles((theme) => ({
  value: {
    fontWeight: theme.typography.fontWeightMedium
  },
  miniContainer: {
    paddingTop: "10px"
  }
}));

const SessionSummary = ({ session }) => {
  const classes = useStyles();

  return (
    <>
      <Grid container className={classes.miniContainer}>
        <Grid item xs={12} sm={5} md={5}>
          {"Session: "}
          <span className={classes.value}>{session.sessionId}</span>
        </Grid>
        <Grid item xs={12} sm={2} md={2}>
          {"Active: "}
          {session.active ? (
            <CheckCircleOutlineRounded color="primary" />
          ) : (
            <RemoveRounded />
          )}
        </Grid>
        <Grid item xs={12} sm={3} md={3}>
          {"Start date: "}
          <span className={classes.value}>{session.startDate}</span>
        </Grid>

        <Grid item xs={12} sm={3} md={3}>
          {"Stop date: "}
          <span className={classes.value}>{session.stopDate || "---"}</span>
        </Grid>

        <Grid item xs={12} sm={3} md={3}>
          {"Running time: "}
          <span className={classes.value}>{session.runningTime}</span>
        </Grid>

        <Grid item xs={12} sm={3} md={3}>
          {"Host: "}
          <span className={classes.value}>{session.hostName}</span>
        </Grid>
      </Grid>
    </>
  );
};

SessionSummary.propTypes = {
  session: PropTypes.object.isRequired
};

export default SessionSummary;
